@@ -1,31 +1,24 @@
 package Stepford::Role::Step::FileGenerator::Atomic;
-$Stepford::Role::Step::FileGenerator::Atomic::VERSION = '0.002010';
+$Stepford::Role::Step::FileGenerator::Atomic::VERSION = '0.002011';
 use strict;
 use warnings;
 use namespace::autoclean;
 
 use Carp qw( croak );
 use File::Temp;
-use Path::Class qw( dir );
+use Path::Class qw( file );
+use Scope::Guard qw( guard );
 use Stepford::Types qw( File );
 
 use Moose::Role;
 
 with 'Stepford::Role::Step::FileGenerator';
 
-has _tempdir => (
-    is       => 'ro',
-    isa      => 'File::Temp::Dir',
-    init_arg => undef,
-    lazy     => 1,
-    default  => sub { File::Temp->newdir() },
-);
-
 has pre_commit_file => (
     is      => 'ro',
     isa     => File,
     lazy    => 1,
-    default => sub { dir( $_[0]->_tempdir() )->file('pre-commit') },
+    builder => '_build_pre_commit_file',
 );
 
 sub BUILD { }
@@ -43,10 +36,23 @@ before BUILD => sub {
     return;
 };
 
-after run => sub {
+sub _build_pre_commit_file {
+    my $self = shift;
+
+    my $final_file = ( $self->productions() )[0];
+    my $reader = $final_file->get_read_method();
+
+    return file( $self->$reader() . '.tmp' );
+}
+
+around run => sub {
+    my $orig = shift;
     my $self = shift;
 
     my $pre_commit = $self->pre_commit_file();
+    my $guard = guard { $pre_commit->remove() if -f $pre_commit };
+
+    $self->$orig(@_);
 
     croak 'The '
         . ( ref $self )
@@ -76,7 +82,7 @@ Stepford::Role::Step::FileGenerator::Atomic - A role for steps that generate a f
 
 =head1 VERSION
 
-version 0.002010
+version 0.002011
 
 =head1 DESCRIPTION
 
